/*
 * BTLDataModel.h
 * MooseTracker
 *
 * Encapsulated all relevant model data for Storywriter.
 * 
 * Created by Matthew Christensen on Tue Aug 03 2004
 * Copyright ¬© 2004 Matthew Christensen. All rights reserved.
 */

#import <Cocoa/Cocoa.h>

@class BTLTemplate;
@class BTLDocument;
@class BTLDocumentInfo;
@class BTLTextStorage;

@interface BTLDataModel : NSObject <NSCoding>
{
	// The associated template object for our data model
	BTLTemplate *template;
	
	// Our associated document object
	BTLDocument *document;
	
	BTLDocumentInfo *documentInfo;
		
	// Our associated text
	BTLTextStorage *text;
	
	// Flag used to indicate that our loaded doc uses an unknown template
	bool unknownTemplateType;
}

#pragma mark Initialization

- (id) init;

	// Designated initializer
- (id) initWithDocument: (BTLDocument *) inDocument;

#pragma mark NSCoding support

- (void)encodeWithCoder:(NSCoder *)encoder;
- (id)initWithCoder:(NSCoder *)decoder;

#pragma mark Encoding/Decoding

- (NSData *) storeToData;
+ (BTLDataModel *) createFromData:  (NSData *) d document: (BTLDocument *) doc;

#pragma mark Accessors

- (BTLTemplate *) template;

- (void) setDocument: (BTLDocument *) doc;

- (BTLTextStorage *) text;
- (void) setText:  (BTLTextStorage *) t;

- (BTLDocumentInfo *) documentInfo;
- (void) setDocumentInfo: (BTLDocumentInfo *) info;

- (bool) unknownTemplateType;
- (void) setUnknownTemplateType: (bool) b;

@end
