/*
 * BTLDocumentInfo.h
 * StoryWriter
 *
 * Metadata about a given document. Used during rendering. 
 * 
 * Created by Matthew Christensen on Tue Aug 24 2004
 * Copyright © 2004 Matthew Christensen. All rights reserved.
 */

#import <Cocoa/Cocoa.h>

@interface BTLDocumentInfo : NSObject 
{
	NSString *documentTitle;
	NSString *documentAuthor;
	NSString *contactInfoOne;
	NSString *contactInfoTwo;
	
	NSMutableArray *autocompleteItems;

	NSFont *currentFont;
	
	// Preferences
	bool autoCapitalize;
	bool useFullDictionary;
	bool autoSaveDocument;
	unsigned autoSaveInterval;	
	bool showCards;
	bool showCardText;
	bool printing;
	bool autoPaginate;
	bool postNotifications;
}

#pragma mark Initialization

// Designated initialzer
- initWithInfo: (NSString *) title documentAuthor: (NSString * ) author autocompleteItems: (NSArray *)items;

#pragma mark Accessors

- (void) disableNotifications;
- (void) enableNotifications;

// Return the title of this document. Can be nil.
- (NSString *) documentTitle;
- (void) setDocumentTitle: (NSString *) s;

// Return the author of this document. Can be nil.
- (NSString *) documentAuthor;
- (void) setDocumentAuthor: (NSString *) s;

// Return the first contact info string for this document. Can be nil.
- (NSString *) contactInfoOne;
- (void) setContactInfoOne: (NSString *) s;

// Return the second contact info string for this document. Can be nil.
- (NSString *) contactInfoTwo;
- (void) setContactInfoTwo: (NSString *) s;

// Return the current font
- (NSFont *) currentFont;
- (void) setCurrentFont: (NSFont *) font;

// Set whether or not words should be auto-capitalized
- (bool) autoCapitalize;
- (void) setAutoCapitalize: (bool) b;

// Set whether or not the full dictionary should be used for autocomplete
- (bool) useFullDictionary;
- (void) setUseFullDictionary: (bool) b;

// Set whether or not words we should auto-save document
- (bool) autoSaveDocument;
- (void) setAutoSaveDocument: (bool) b;

// Set interval to autosave document at (in minutes)
- (unsigned) autoSaveInterval;
- (void) setAutoSaveInterval: (unsigned) i;

// Show card in the edit area?
- (bool) showCards;
- (void) setShowCards: (bool) b;

// Show card text in the edit area?
- (bool) showCardText;
- (void) setShowCardText: (bool) b;

// Show card notes
// Are we in the process of printing?
- (bool) printing;
- (void) setPrinting: (bool) b;

// Enable or disable auto-pagination
- (bool) autoPaginate;
- (void) setAutoPaginate: (bool) b;

#pragma mark Autocomplete

// Return our list of autocomplete items
- (NSArray *) autocompleteItems;

// Add a new autocomplete item to the list
- (void) addAutocompleteItem: (NSString *) item;

// Clear all autocomplete items
- (void) clearAutocompleteItems;

@end

// Notification fired when document info changes
extern NSString *BTLDocumentInfoNotification;
