/*
 * BTLPageTemplate.h
 * StoryWriter
 *
 * Used to format a page for printing (or preview). 
 * 
 * Created by Matthew Christensen on Tue Aug 24 2004
 * Copyright © 2004 Matthew Christensen. All rights reserved.
 */


#import <Cocoa/Cocoa.h>

@class BTLDocumentInfo;

@interface BTLPageTemplate : NSObject 
{
	// Distance, in inches, from left (relative)
	float leftMargin;
	
	// Distance, in inches, from right (relative)
	float rightMargin;

	// Distance, in inches, from top (relative)
	float topMargin;

	// Distance, in inches, from bottom (relative)
	float bottomMargin;
}

#pragma mark Initialization

// Designated initializer
- init;

#pragma mark Rendering

// Update a print info object for this template (margins, etc)
- (void) updatePrintInfo: (NSPrintInfo *) info;

// Given a specific page number, and a view containing the text already layed out,
// add any formatting. The margins are the printable area, though you can write outside them for headers
// and whatnot
- (void) formatPageView: (NSView *) v documentInfo: (BTLDocumentInfo *) md pageNumber: (unsigned) pageNumber margins: (NSRect) margins;

// Return an NSDictionary containing the formatting for this document as RTF attributes
- (NSDictionary *) rtfAttributes;

@end
