/*
 * BTLPrintPageView.h
 * MooseTracker
 *
 * Custom view class that represents a printable page. A convinience method
 * returns the margins
 * 
 * Created by Matthew Christensen on Wed Sept 01 2004
 * Copyright ¬© 2004 Matthew Christensen. All rights reserved.
 */
#import <Cocoa/Cocoa.h>

@class BTLPageTemplate;
@class BTLDocumentInfo;
@class BTLTextView;

#define CARD_MARKER_OBJECT_KEY	@"BTLCardMarkerKey"
#define DOUBLE_CLICK_KEY		@"BTLDoubleClickKey"

@interface BTLPrintPageView : NSView 
{
	NSRect inMarginRect;
	BTLPageTemplate *pageTemplate;
	BTLDocumentInfo *documentInfo;
	unsigned pageNumber;
	
	// Associated editor
	BTLTextView *editor;

	// Scene marker management
	NSMutableDictionary *textAttributes;
	NSImage *arrowImage;
	NSMutableArray *cardLocations;
	
	// Used to track when we need to update text because it has changed
	uint32_t textVersionID; 
}

// Designated initializer
- initWithPrintInfo: (NSPrintInfo *) printInfo pageTemplate: (BTLPageTemplate *) t documentInfo: (BTLDocumentInfo *) info pageNumber: (unsigned) num;

#pragma mark Accessors

// Returns the rect that is within our margins
- (NSRect) rectInMargins;

// Returns our associated page template, used for
// rendering
- (BTLPageTemplate *) pageTemplate;

// Returns our associated document info, used for
// rendering
- (BTLDocumentInfo *) documentInfo;

// Set/get the optional editor. This will add it as a subview as well.
- (void) setEditor: (BTLTextView *) editor;
- (BTLTextView *) editor;
- (void) setDocumentInfo: (BTLDocumentInfo *) info;

#pragma mark Card location management

// Draw the cards to the page
- (void) drawCards: (NSRect) r;
- (void) calculateCardLocations;

@end

// Notification that lets other classes know that a card should be selected
extern NSString *BTLSelectCardNotification;
