/*
 * BTLTextContainer.h
 * StoryWriter
 *
 * Subclass of NSTextContainer that is aware of whether or not it needs pagination.
 * 
 * Created by Matthew Christensen on Friday Oct 22 2004
 * Copyright © 2004 Matthew Christensen. All rights reserved.
 */

#import <Cocoa/Cocoa.h>


@interface BTLTextContainer : NSTextContainer 
{
	bool needsPagination;
	
	NSString *lastLine;
	bool hasMore;
	NSString *continuedCharacter;
	NSSize originalSize;
	bool hasPageBreak;
	NSSize prePageBreakSize;
}

#pragma mark Initialization

- init;

- initWithContainerSize: (NSSize) s;

#pragma mark Accessors

- (bool) needsPagination;
- (void) setNeedsPagination: (bool) b;

- (bool) hasMore;
- (void) setHasMore: (bool) b;

- (NSString *) lastLine;
- (void) setLastLine: (NSString *) s;

- (NSString *) continuedCharacter;
- (void) setContinuedCharacter: (NSString *) c;

- (NSSize) originalSize;
- (void) setOriginalSize: (NSSize) s;


#pragma mark Size manipuplation

- (void) setContainerAndViewSize: (NSSize) size;
- (void) restoreOriginalSize;

- (void) removePageBreak;
- (void) addPageBreak: (unsigned) newHeight;
- (bool) hasPageBreak;

// Reset everything to defaults
- (void) reset;

@end
